==> eam-wshub-proxyclient-11.5-10-sources.jar: org/openapplications/oagis_segments/DATETIME.java <==

package org.openapplications.oagis_segments;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * <p>Classe Java pour DATETIME complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DATETIME">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}YEAR"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}MONTH"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}DAY"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}HOUR"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}MINUTE"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SECOND"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SUBSECOND"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}TIMEZONE"/>
 *       &lt;/sequence>
 *       &lt;attribute name="qualifier" use="required" type="{http://www.openapplications.org/oagis_segments}DATETIMEqual" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DATETIME", propOrder = {
    "year",
    "month",
    "day",
    "hour",
    "minute",
    "second",
    "subsecond",
    "timezone"
})
public class DATETIME {

    @XmlElement(name = "YEAR", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    @XmlSchemaType(name = "gYear")
    protected XMLGregorianCalendar year;
    @XmlElement(name = "MONTH", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger month;
    @XmlElement(name = "DAY", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger day;
    @XmlElement(name = "HOUR", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger hour;
    @XmlElement(name = "MINUTE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger minute;
    @XmlElement(name = "SECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger second;
    @XmlElement(name = "SUBSECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger subsecond;
    @XmlElement(name = "TIMEZONE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected String timezone;
    @XmlAttribute(name = "qualifier", required = true)
    protected DATETIMEqual qualifier;

    /**
     * Obtient la valeur de la propriété year.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getYEAR() {
        return year;
    }

    /**
     * Définit la valeur de la propriété year.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setYEAR(XMLGregorianCalendar value) {
        this.year = value;
    }

    /**
     * Obtient la valeur de la propriété month.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMONTH() {
        return month;
    }

    /**
     * Définit la valeur de la propriété month.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMONTH(BigInteger value) {
        this.month = value;
    }

    /**
     * Obtient la valeur de la propriété day.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getDAY() {
        return day;
    }

    /**
     * Définit la valeur de la propriété day.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setDAY(BigInteger value) {
        this.day = value;
    }

    /**
     * Obtient la valeur de la propriété hour.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getHOUR() {
        return hour;
    }

    /**
     * Définit la valeur de la propriété hour.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setHOUR(BigInteger value) {
        this.hour = value;
    }

    /**
     * Obtient la valeur de la propriété minute.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMINUTE() {
        return minute;
    }

    /**
     * Définit la valeur de la propriété minute.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMINUTE(BigInteger value) {
        this.minute = value;
    }

    /**
     * Obtient la valeur de la propriété second.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSECOND() {
        return second;
    }

    /**
     * Définit la valeur de la propriété second.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSECOND(BigInteger value) {
        this.second = value;
    }

    /**
     * Obtient la valeur de la propriété subsecond.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSUBSECOND() {
        return subsecond;
    }

    /**
     * Définit la valeur de la propriété subsecond.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSUBSECOND(BigInteger value) {
        this.subsecond = value;
    }

    /**
     * Obtient la valeur de la propriété timezone.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTIMEZONE() {
        return timezone;
    }

    /**
     * Définit la valeur de la propriété timezone.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTIMEZONE(String value) {
        this.timezone = value;
    }

    /**
     * Obtient la valeur de la propriété qualifier.
     * 
     * @return
     *     possible object is
     *     {@link DATETIMEqual }
     *     
     */
    public DATETIMEqual getQualifier() {
        return qualifier;
    }

    /**
     * Définit la valeur de la propriété qualifier.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIMEqual }
     *     
     */
    public void setQualifier(DATETIMEqual value) {
        this.qualifier = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: org/openapplications/oagis_segments/DATETIME.java <==

package org.openapplications.oagis_segments;

import java.math.BigInteger;
import javax.xml.datatype.XMLGregorianCalendar;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DATETIME complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="DATETIME">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.openapplications.org/oagis_fields}YEAR"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}MONTH"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}DAY"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}HOUR"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}MINUTE"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}SECOND"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}SUBSECOND"/>
 *         <element ref="{http://www.openapplications.org/oagis_fields}TIMEZONE"/>
 *       </sequence>
 *       <attribute name="qualifier" use="required" type="{http://www.openapplications.org/oagis_segments}DATETIMEqual" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DATETIME", propOrder = {
    "year",
    "month",
    "day",
    "hour",
    "minute",
    "second",
    "subsecond",
    "timezone"
})
public class DATETIME {

    @XmlElement(name = "YEAR", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    @XmlSchemaType(name = "gYear")
    protected XMLGregorianCalendar year;
    @XmlElement(name = "MONTH", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger month;
    @XmlElement(name = "DAY", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger day;
    @XmlElement(name = "HOUR", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger hour;
    @XmlElement(name = "MINUTE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger minute;
    @XmlElement(name = "SECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger second;
    @XmlElement(name = "SUBSECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger subsecond;
    @XmlElement(name = "TIMEZONE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected String timezone;
    @XmlAttribute(name = "qualifier", required = true)
    protected DATETIMEqual qualifier;

    /**
     * Gets the value of the year property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getYEAR() {
        return year;
    }

    /**
     * Sets the value of the year property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setYEAR(XMLGregorianCalendar value) {
        this.year = value;
    }

    /**
     * Gets the value of the month property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMONTH() {
        return month;
    }

    /**
     * Sets the value of the month property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMONTH(BigInteger value) {
        this.month = value;
    }

    /**
     * Gets the value of the day property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getDAY() {
        return day;
    }

    /**
     * Sets the value of the day property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setDAY(BigInteger value) {
        this.day = value;
    }

    /**
     * Gets the value of the hour property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getHOUR() {
        return hour;
    }

    /**
     * Sets the value of the hour property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setHOUR(BigInteger value) {
        this.hour = value;
    }

    /**
     * Gets the value of the minute property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMINUTE() {
        return minute;
    }

    /**
     * Sets the value of the minute property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMINUTE(BigInteger value) {
        this.minute = value;
    }

    /**
     * Gets the value of the second property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSECOND() {
        return second;
    }

    /**
     * Sets the value of the second property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSECOND(BigInteger value) {
        this.second = value;
    }

    /**
     * Gets the value of the subsecond property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSUBSECOND() {
        return subsecond;
    }

    /**
     * Sets the value of the subsecond property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSUBSECOND(BigInteger value) {
        this.subsecond = value;
    }

    /**
     * Gets the value of the timezone property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTIMEZONE() {
        return timezone;
    }

    /**
     * Sets the value of the timezone property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTIMEZONE(String value) {
        this.timezone = value;
    }

    /**
     * Gets the value of the qualifier property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIMEqual }
     *     
     */
    public DATETIMEqual getQualifier() {
        return qualifier;
    }

    /**
     * Sets the value of the qualifier property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIMEqual }
     *     
     */
    public void setQualifier(DATETIMEqual value) {
        this.qualifier = value;
    }

}
